@@ -109,9 +109,9 @@ def test_run(project_root: Path, request) -> Path:
     return test_results_dir
 
 
-@pytest.fixture(scope="function")
-def py_config(project_root: Path, request) -> PyleniumConfig:
-    """Initialize a PyleniumConfig for each test
+@pytest.fixture(scope="session")
+def _py_config(project_root, request) -> PyleniumConfig:
+    """Read the PyleniumConfig for the test session
 
     1. This starts by deserializing the user-created pylenium.json from the Project Root.
     2. If that file is not found, then proceed with Pylenium Defaults.
@@ -169,6 +169,15 @@ def py_config(project_root: Path, request) -> PyleniumConfig:
     return config
 
 
+@pytest.fixture(scope="function")
+def py_config(_py_config) -> PyleniumConfig:
+    """Get a fresh copy of the PyleniumConfig for each test
+
+    See _py_config for how the initial configuration is read.
+    """
+    return copy.deepcopy(_py_config)
+
+
 @pytest.fixture(scope="function")
 def test_case(test_run: Path, py_config, request) -> TestCase:
     """Manages data pertaining to the currently running Test Function or Case.
