@@ -32,7 +32,7 @@ class SwitchTo:
             # Switch to an iframe
             py.switch_to.frame('main-frame')
         """
-        self._py.log.info(f"[STEP] py.switch_to.frame() - Switch to frame using name or id: ``{name_or_id}``")
+        self._py.log.debug(f"[STEP] py.switch_to.frame() - Switch to frame using name or id: ``{name_or_id}``")
         self._py.wait(timeout).until(FrameIsAvailable(name_or_id))
         return self._py
 
@@ -47,7 +47,7 @@ class SwitchTo:
             iframe = py.get('iframe')
             py.switch_to.frame_by_element(iframe)
         """
-        self._py.log.info("[STEP] py.switch_to.frame_by_element() - Switch to frame using an Element.")
+        self._py.log.debug("[STEP] py.switch_to.frame_by_element() - Switch to frame using an Element.")
         self._py.wait(timeout).until(ec.frame_to_be_available_and_switch_to_it(element.locator))
         return self._py
 
@@ -56,13 +56,13 @@ class SwitchTo:
 
         If the parent frame is the current context, nothing happens.
         """
-        self._py.log.info("[STEP] py.switch_to.parent_frame() - Switch to the parent frame")
+        self._py.log.debug("[STEP] py.switch_to.parent_frame() - Switch to the parent frame")
         self._py.webdriver.switch_to.parent_frame()
         return self._py
 
     def default_content(self):
         """Switch the driver's context to the default content."""
-        self._py.log.info("[STEP] py.switch_to.default_content() - Switch to default content of this browser session")
+        self._py.log.debug("[STEP] py.switch_to.default_content() - Switch to default content of this browser session")
         self._py.webdriver.switch_to.default_content()
         return self._py
 
@@ -95,11 +95,11 @@ class SwitchTo:
         """
         if index:
             handle = self._py.webdriver.window_handles[index]
-            self._py.log.info(f"[STEP] py.switch_to.window() - Switch to a Tab or Window by index: ``{index}``")
+            self._py.log.debug(f"[STEP] py.switch_to.window() - Switch to a Tab or Window by index: ``{index}``")
             self._py.webdriver.switch_to.window(handle)
             return self._py
         elif name_or_handle:
-            self._py.log.info(
+            self._py.log.debug(
                 f"[STEP] py.switch_to.window() - Switch to Tab or Window by name or handle: ``{name_or_handle}``"
             )
             self._py.webdriver.switch_to.window(name_or_handle)
